@@ -24,7 +24,7 @@
 #ifndef _C_JHASH_H
 #define _C_JHASH_H
 
-#include <stdint.h>
+#include <stdint.h> // NOLINT
 
 #define c_hashsize(n) ((uint8_t) 1 << (n))
 #define c_hashmask(n) (xhashsize(n) - 1)
@@ -57,15 +57,15 @@
  */
 #define _c_mix(a,b,c) \
 { \
-  a -= b; a -= c; a ^= (c>>13); \
-  b -= c; b -= a; b ^= (a<<8); \
-  c -= a; c -= b; c ^= (b>>13); \
-  a -= b; a -= c; a ^= (c>>12);  \
-  b -= c; b -= a; b ^= (a<<16); \
-  c -= a; c -= b; c ^= (b>>5); \
-  a -= b; a -= c; a ^= (c>>3);  \
-  b -= c; b -= a; b ^= (a<<10); \
-  c -= a; c -= b; c ^= (b>>15); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>13); \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<8); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>13); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>12);  \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<16); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>5); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>3);  \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<10); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>15); \
 }
 
 /**
@@ -88,18 +88,18 @@
  */
 #define _c_mix64(a,b,c) \
 { \
-  a -= b; a -= c; a ^= (c>>43); \
-  b -= c; b -= a; b ^= (a<<9); \
-  c -= a; c -= b; c ^= (b>>8); \
-  a -= b; a -= c; a ^= (c>>38); \
-  b -= c; b -= a; b ^= (a<<23); \
-  c -= a; c -= b; c ^= (b>>5); \
-  a -= b; a -= c; a ^= (c>>35); \
-  b -= c; b -= a; b ^= (a<<49); \
-  c -= a; c -= b; c ^= (b>>11); \
-  a -= b; a -= c; a ^= (c>>12); \
-  b -= c; b -= a; b ^= (a<<18); \
-  c -= a; c -= b; c ^= (b>>22); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>43); \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<9); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>8); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>38); \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<23); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>5); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>35); \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<49); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>11); \
+  (a) -= (b); (a) -= (c); (a) ^= ((c)>>12); \
+  (b) -= (c); (b) -= (a); (b) ^= ((a)<<18); \
+  (c) -= (a); (c) -= (b); (c) ^= ((b)>>22); \
 }
 
 /**
