@@ -23,7 +23,6 @@
 #include <QElapsedTimer>
 #include <QUrl>
 #include <QDir>
-#include <QStandardPaths>
 #include <sqlite3.h>
 
 #include "common/syncjournaldb.h"
@@ -104,15 +103,11 @@ SyncJournalDb::SyncJournalDb(const QString &dbFilePath, QObject *parent)
     }
 }
 
-QString SyncJournalDb::makeDbName(const QUrl &remoteUrl,
+QString SyncJournalDb::makeDbName(const QString &localPath,
+    const QUrl &remoteUrl,
     const QString &remotePath,
     const QString &user)
 {
-    const QString dbPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
-    if (!QDir(dbPath).exists()) {
-        QDir().mkdir(dbPath);
-    }
-
     QString journalPath = QLatin1String("._sync_");
 
     QString key = QString::fromUtf8("%1@%2:%3").arg(user, remoteUrl.toString(), remotePath);
@@ -121,16 +116,17 @@ QString SyncJournalDb::makeDbName(const QUrl &remoteUrl,
     journalPath.append(ba.left(6).toHex());
     journalPath.append(".db");
 
-    journalPath = dbPath + QLatin1Char('/') + journalPath;
-
     // If the journal doesn't exist and we can't create a file
     // at that location, try again with a journal name that doesn't
     // have the ._ prefix.
     //
+    // The disadvantage of that filename is that it will only be ignored
+    // by client versions >2.3.2.
+    //
     // See #5633: "._*" is often forbidden on samba shared folders.
 
     // If it exists already, the path is clearly usable
-    QFile file(QDir(dbPath).filePath(journalPath));
+    QFile file(QDir(localPath).filePath(journalPath));
     if (file.exists()) {
         return journalPath;
     }
@@ -145,7 +141,7 @@ QString SyncJournalDb::makeDbName(const QUrl &remoteUrl,
 
     // Can we create it if we drop the underscore?
     QString alternateJournalPath = journalPath.mid(2).prepend(".");
-    QFile file2(QDir(dbPath).filePath(alternateJournalPath));
+    QFile file2(QDir(localPath).filePath(alternateJournalPath));
     if (file2.open(QIODevice::ReadWrite)) {
         // The alternative worked, use it
         qCInfo(lcDb) << "Using alternate database path" << alternateJournalPath;
@@ -729,10 +725,10 @@ bool SyncJournalDb::updateMetadataTableStructure()
         SqlQuery query(_db);
         query.prepare("ALTER TABLE metadata ADD COLUMN isE2eEncrypted INTEGER;");
         if (!query.exec()) {
-            sqlFail("updateMetadataTableStructure: add e2eMangledName column", query);
+            sqlFail("updateMetadataTableStructure: add isE2eEncrypted column", query);
             re = false;
         }
-        commitInternal("update database structure: add e2eMangledName col");
+        commitInternal("update database structure: add isE2eEncrypted col");
     }
 
     if (!tableColumns("uploadinfo").contains("contentChecksum")) {
@@ -745,6 +741,15 @@ bool SyncJournalDb::updateMetadataTableStructure()
         commitInternal("update database structure: add contentChecksum col for uploadinfo");
     }
 
+    if (true) {
+        SqlQuery query(_db);
+        query.prepare("CREATE INDEX IF NOT EXISTS metadata_e2e_id ON metadata(e2eMangledName);");
+        if (!query.exec()) {
+            sqlFail("updateMetadataTableStructure: create index e2eMangledName", query);
+            re = false;
+        }
+        commitInternal("update database structure: add e2eMangledName index");
+    }
 
     return re;
 }
@@ -1447,7 +1452,7 @@ SyncJournalDb::UploadInfo SyncJournalDb::getUploadInfo(const QString &file)
         if (_getUploadInfoQuery.next()) {
             bool ok = true;
             res._chunk = _getUploadInfoQuery.intValue(0);
-            res._transferid = _getUploadInfoQuery.intValue(1);
+            res._transferid = _getUploadInfoQuery.int64Value(1);
             res._errorCount = _getUploadInfoQuery.intValue(2);
             res._size = _getUploadInfoQuery.int64Value(3);
             res._modtime = _getUploadInfoQuery.int64Value(4);
@@ -2022,6 +2027,23 @@ QByteArrayList SyncJournalDb::conflictRecordPaths()
     return paths;
 }
 
+QByteArray SyncJournalDb::conflictFileBaseName(const QByteArray &conflictName)
+{
+    auto conflict = conflictRecord(conflictName);
+    QByteArray result;
+    if (conflict.isValid()) {
+        getFileRecordsByFileId(conflict.baseFileId, [&result](const SyncJournalFileRecord &record) {
+            if (!record._path.isEmpty())
+                result = record._path;
+        });
+    }
+
+    if (result.isEmpty()) {
+        result = Utility::conflictFileBaseNameFromPattern(conflictName);
+    }
+    return result;
+}
+
 void SyncJournalDb::clearFileTable()
 {
     QMutexLocker lock(&_mutex);
