@@ -133,7 +133,7 @@ bool csync_is_windows_reserved_word(const char *filename)
 
 static CSYNC_EXCLUDE_TYPE _csync_excluded_common(const char *path, bool excludeConflictFiles)
 {
-    const char *bname = NULL;
+    const char *bname = nullptr;
     size_t blen = 0;
     int rc = -1;
     CSYNC_EXCLUDE_TYPE match = CSYNC_NOT_EXCLUDED;
@@ -261,9 +261,7 @@ ExcludedFiles::ExcludedFiles(QString localPath)
         addInTreeExcludeFilePath(fi.absoluteFilePath());
 }
 
-ExcludedFiles::~ExcludedFiles()
-{
-}
+ExcludedFiles::~ExcludedFiles() = default;
 
 void ExcludedFiles::addExcludeFilePath(const QString &path)
 {
@@ -319,17 +317,20 @@ bool ExcludedFiles::loadExcludeFile(const QByteArray & basePath, const QString &
     if (!f.open(QIODevice::ReadOnly))
         return false;
 
+    QList<QByteArray> patterns;
     while (!f.atEnd()) {
         QByteArray line = f.readLine().trimmed();
         if (line.isEmpty() || line.startsWith('#'))
             continue;
         csync_exclude_expand_escapes(line);
-        _allExcludes[basePath].append(line);
+        patterns.append(line);
     }
+    _allExcludes.insert(basePath, patterns);
 
     // nothing to prepare if the user decided to not exclude anything
-    if(_allExcludes.size())
+    if (!_allExcludes.value(basePath).isEmpty()){
         prepare(basePath);
+    }
 
     return true;
 }
@@ -346,7 +347,8 @@ bool ExcludedFiles::reloadExcludeFiles()
     _fullRegexDir.clear();
 
     bool success = true;
-    for (const auto& basePath : _excludeFiles.keys()) {
+    const auto keys = _excludeFiles.keys();
+    for (const auto& basePath : keys) {
         for (const auto& file : _excludeFiles.value(basePath)) {
             success = loadExcludeFile(basePath, file);
         }
@@ -412,10 +414,12 @@ CSYNC_EXCLUDE_TYPE ExcludedFiles::traversalPatternMatch(const char *path, ItemTy
 
     // Directories are guaranteed to be visited before their files
     if (filetype == ItemTypeDirectory) {
-        QFileInfo fi = QFileInfo(_localPath + path + "/.sync-exclude.lst");
+        const auto basePath = QString(_localPath + path + QLatin1Char('/')).toUtf8();
+        const auto fi = QFileInfo(basePath + QStringLiteral(".sync-exclude.lst"));
+
         if (fi.isReadable()) {
             addInTreeExcludeFilePath(fi.absoluteFilePath());
-            loadExcludeFile(fi.absolutePath().toUtf8(), fi.absoluteFilePath());
+            loadExcludeFile(basePath, fi.absoluteFilePath());
         }
     }
 
@@ -667,7 +671,8 @@ void ExcludedFiles::prepare()
     _fullRegexFile.clear();
     _fullRegexDir.clear();
 
-    for (auto const & basePath : _allExcludes.keys())
+    const auto keys = _allExcludes.keys();
+    for (auto const & basePath : keys)
         prepare(basePath);
 }
 
