@@ -51,29 +51,28 @@ void CloudProviderManager::registerSignals()
 
 CloudProviderManager::CloudProviderManager(QObject *parent) : QObject(parent)
 {
-    _map = new QMap<QString, CloudProviderWrapper*>();
-    QString busName = QString(LIBCLOUDPROVIDERS_DBUS_BUS_NAME);
-    g_bus_own_name (G_BUS_TYPE_SESSION, busName.toAscii().data(), G_BUS_NAME_OWNER_FLAGS_NONE, nullptr, on_name_acquired, nullptr, this, nullptr);
+    _folder_index = 0;
+    g_bus_own_name (G_BUS_TYPE_SESSION, LIBCLOUDPROVIDERS_DBUS_BUS_NAME, G_BUS_NAME_OWNER_FLAGS_NONE, nullptr, on_name_acquired, nullptr, this, nullptr);
 }
 
 void CloudProviderManager::slotFolderListChanged(const Folder::Map &folderMap)
 {
-    QMapIterator<QString, CloudProviderWrapper*> i(*_map);
+    QMapIterator<QString, CloudProviderWrapper*> i(_map);
     while (i.hasNext()) {
         i.next();
         if (!folderMap.contains(i.key())) {
             cloud_providers_provider_exporter_remove_account(_providerExporter, i.value()->accountExporter());
-            delete _map->find(i.key()).value();
-            _map->remove(i.key());
+            delete _map.find(i.key()).value();
+            _map.remove(i.key());
         }
     }
 
     Folder::MapIterator j(folderMap);
     while (j.hasNext()) {
         j.next();
-        if (!_map->contains(j.key())) {
-            auto *cpo = new CloudProviderWrapper(this, j.value(), _providerExporter);
-            _map->insert(j.key(), cpo);
+        if (!_map.contains(j.key())) {
+            auto *cpo = new CloudProviderWrapper(this, j.value(), _folder_index++, _providerExporter);
+            _map.insert(j.key(), cpo);
         }
     }
 }
