@@ -1,13 +1,13 @@
 #include "webflowcredentials.h"
 
 #include "creds/httpcredentials.h"
+#include "creds/keychainchunk.h"
 
 #include <QAuthenticator>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QPointer>
 #include <QTimer>
-#include <keychain.h>
 #include <QDialog>
 #include <QVBoxLayout>
 #include <QLabel>
@@ -18,13 +18,12 @@
 #include "theme.h"
 #include "wizard/webview.h"
 #include "webflowcredentialsdialog.h"
-#include "keychainchunk.h"
 
 using namespace QKeychain;
 
 namespace OCC {
 
-Q_LOGGING_CATEGORY(lcWebFlowCredentials, "sync.credentials.webflow", QtInfoMsg)
+Q_LOGGING_CATEGORY(lcWebFlowCredentials, "nextcloud.sync.credentials.webflow", QtInfoMsg)
 
 namespace {
     const char userC[] = "user";
@@ -86,14 +85,7 @@ static void addSettingsToJob(Account *account, QKeychain::Job *job)
 }
 #endif
 
-WebFlowCredentials::WebFlowCredentials()
-    : _ready(false)
-    , _credentialsValid(false)
-    , _keychainMigration(false)
-    , _retryOnKeyChainError(false)
-{
-
-}
+WebFlowCredentials::WebFlowCredentials() = default;
 
 WebFlowCredentials::WebFlowCredentials(const QString &user, const QString &password, const QSslCertificate &certificate, const QSslKey &key, const QList<QSslCertificate> &caCertificates)
     : _user(user)
@@ -103,8 +95,6 @@ WebFlowCredentials::WebFlowCredentials(const QString &user, const QString &passw
     , _clientSslCaCertificates(caCertificates)
     , _ready(true)
     , _credentialsValid(true)
-    , _keychainMigration(false)
-    , _retryOnKeyChainError(false)
 {
 
 }
@@ -152,7 +142,7 @@ void WebFlowCredentials::fetchFromKeychain() {
 void WebFlowCredentials::askFromUser() {
     // Determine if the old flow has to be used (GS for now)
     // Do a DetermineAuthTypeJob to make sure that the server is still using Flow2
-    DetermineAuthTypeJob *job = new DetermineAuthTypeJob(_account->sharedFromThis(), this);
+    auto job = new DetermineAuthTypeJob(_account->sharedFromThis(), this);
     connect(job, &DetermineAuthTypeJob::authType, [this](DetermineAuthTypeJob::AuthType type) {
         // LoginFlowV2 > WebViewFlow > OAuth > Shib > Basic
         bool useFlow2 = (type != DetermineAuthTypeJob::WebViewFlow);
@@ -245,9 +235,10 @@ void WebFlowCredentials::persist() {
 
     // write cert if there is one
     if (!_clientSslCertificate.isNull()) {
-        auto *job = new KeychainChunk::WriteJob(_account,
-                                                _user + clientCertificatePEMC,
-                                                _clientSslCertificate.toPem());
+        auto job = new KeychainChunk::WriteJob(_account,
+                                               _user + clientCertificatePEMC,
+                                               _clientSslCertificate.toPem(),
+                                               this);
         connect(job, &KeychainChunk::WriteJob::finished, this, &WebFlowCredentials::slotWriteClientCertPEMJobDone);
         job->start();
     } else {
@@ -258,14 +249,13 @@ void WebFlowCredentials::persist() {
 
 void WebFlowCredentials::slotWriteClientCertPEMJobDone(KeychainChunk::WriteJob *writeJob)
 {
-    if(writeJob)
-        writeJob->deleteLater();
-
+    Q_UNUSED(writeJob)
     // write ssl key if there is one
     if (!_clientSslKey.isNull()) {
-        auto *job = new KeychainChunk::WriteJob(_account,
-                                                _user + clientKeyPEMC,
-                                                _clientSslKey.toPem());
+        auto job = new KeychainChunk::WriteJob(_account,
+                                               _user + clientKeyPEMC,
+                                               _clientSslKey.toPem(),
+                                               this);
         connect(job, &KeychainChunk::WriteJob::finished, this, &WebFlowCredentials::slotWriteClientKeyPEMJobDone);
         job->start();
     } else {
@@ -293,9 +283,10 @@ void WebFlowCredentials::writeSingleClientCaCertPEM()
             return;
         }
 
-        auto *job = new KeychainChunk::WriteJob(_account,
-                                                _user + clientCaCertificatePEMC + QString::number(index),
-                                                cert.toPem());
+        auto job = new KeychainChunk::WriteJob(_account,
+                                               _user + clientCaCertificatePEMC + QString::number(index),
+                                               cert.toPem(),
+                                               this);
         connect(job, &KeychainChunk::WriteJob::finished, this, &WebFlowCredentials::slotWriteClientCaCertsPEMJobDone);
         job->start();
     } else {
@@ -305,9 +296,7 @@ void WebFlowCredentials::writeSingleClientCaCertPEM()
 
 void WebFlowCredentials::slotWriteClientKeyPEMJobDone(KeychainChunk::WriteJob *writeJob)
 {
-    if(writeJob)
-        writeJob->deleteLater();
-
+    Q_UNUSED(writeJob)
     _clientSslCaCertificatesWriteQueue.clear();
 
     // write ca certs if there are any
@@ -330,8 +319,6 @@ void WebFlowCredentials::slotWriteClientCaCertsPEMJobDone(KeychainChunk::WriteJo
             qCWarning(lcWebFlowCredentials) << "Error while writing client CA cert" << writeJob->errorString();
         }
 
-        writeJob->deleteLater();
-
         if (!_clientSslCaCertificatesWriteQueue.isEmpty()) {
             // next ca cert
             writeSingleClientCaCertPEM();
@@ -340,7 +327,7 @@ void WebFlowCredentials::slotWriteClientCaCertsPEMJobDone(KeychainChunk::WriteJo
     }
 
     // done storing ca certs, time for the password
-    WritePasswordJob *job = new WritePasswordJob(Theme::instance()->appName());
+    auto job = new WritePasswordJob(Theme::instance()->appName(), this);
 #if defined(KEYCHAINCHUNK_ENABLE_INSECURE_FALLBACK)
     addSettingsToJob(_account, job);
 #endif
@@ -360,8 +347,6 @@ void WebFlowCredentials::slotWriteJobDone(QKeychain::Job *job)
     default:
         qCWarning(lcWebFlowCredentials) << "Error while writing password" << job->errorString();
     }
-    WritePasswordJob *wjob = qobject_cast<WritePasswordJob *>(job);
-    wjob->deleteLater();
 }
 
 void WebFlowCredentials::invalidateToken() {
@@ -390,13 +375,9 @@ void WebFlowCredentials::forgetSensitiveData() {
         return;
     }
 
-    DeletePasswordJob *job = new DeletePasswordJob(Theme::instance()->appName());
+    auto job = new DeletePasswordJob(Theme::instance()->appName(), this);
     job->setInsecureFallback(false);
     job->setKey(kck);
-    connect(job, &Job::finished, this, [](QKeychain::Job *job) {
-        DeletePasswordJob *djob = qobject_cast<DeletePasswordJob *>(job);
-        djob->deleteLater();
-    });
     job->start();
 
     invalidateToken();
@@ -447,30 +428,16 @@ void WebFlowCredentials::slotFinished(QNetworkReply *reply) {
 
 void WebFlowCredentials::fetchFromKeychainHelper() {
     // Read client cert from keychain
-    auto *job = new KeychainChunk::ReadJob(_account,
-                                           _user + clientCertificatePEMC,
-                                           _keychainMigration);
+    auto job = new KeychainChunk::ReadJob(_account,
+                                          _user + clientCertificatePEMC,
+                                          _keychainMigration,
+                                          this);
     connect(job, &KeychainChunk::ReadJob::finished, this, &WebFlowCredentials::slotReadClientCertPEMJobDone);
     job->start();
 }
 
 void WebFlowCredentials::slotReadClientCertPEMJobDone(KeychainChunk::ReadJob *readJob)
 {
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    Q_ASSERT(!readJob->insecureFallback()); // If insecureFallback is set, the next test would be pointless
-    if (_retryOnKeyChainError && (readJob->error() == QKeychain::NoBackendAvailable
-            || readJob->error() == QKeychain::OtherError)) {
-        // Could be that the backend was not yet available. Wait some extra seconds.
-        // (Issues #4274 and #6522)
-        // (For kwallet, the error is OtherError instead of NoBackendAvailable, maybe a bug in QtKeychain)
-        qCInfo(lcWebFlowCredentials) << "Backend unavailable (yet?) Retrying in a few seconds." << readJob->errorString();
-        QTimer::singleShot(10000, this, &WebFlowCredentials::fetchFromKeychainHelper);
-        _retryOnKeyChainError = false;
-        return;
-    }
-    _retryOnKeyChainError = false;
-#endif
-
     // Store PEM in memory
     if (readJob->error() == NoError && readJob->binaryData().length() > 0) {
         QList<QSslCertificate> sslCertificateList = QSslCertificate::fromData(readJob->binaryData(), QSsl::Pem);
@@ -479,12 +446,11 @@ void WebFlowCredentials::slotReadClientCertPEMJobDone(KeychainChunk::ReadJob *re
         }
     }
 
-    readJob->deleteLater();
-
     // Load key too
-    auto *job = new KeychainChunk::ReadJob(_account,
-                                           _user + clientKeyPEMC,
-                                           _keychainMigration);
+    auto job = new KeychainChunk::ReadJob(_account,
+                                          _user + clientKeyPEMC,
+                                          _keychainMigration,
+                                          this);
     connect(job, &KeychainChunk::ReadJob::finished, this, &WebFlowCredentials::slotReadClientKeyPEMJobDone);
     job->start();
 }
@@ -511,8 +477,6 @@ void WebFlowCredentials::slotReadClientKeyPEMJobDone(KeychainChunk::ReadJob *rea
         qCWarning(lcWebFlowCredentials) << "Unable to read client key" << readJob->errorString();
     }
 
-    readJob->deleteLater();
-
     // Start fetching client CA certs
     _clientSslCaCertificates.clear();
 
@@ -523,9 +487,10 @@ void WebFlowCredentials::readSingleClientCaCertPEM()
 {
     // try to fetch a client ca cert
     if (_clientSslCaCertificates.count() < _clientSslCaCertificatesMaxCount) {
-        auto *job = new KeychainChunk::ReadJob(_account,
-                                               _user + clientCaCertificatePEMC + QString::number(_clientSslCaCertificates.count()),
-                                               _keychainMigration);
+        auto job = new KeychainChunk::ReadJob(_account,
+                                              _user + clientCaCertificatePEMC + QString::number(_clientSslCaCertificates.count()),
+                                              _keychainMigration,
+                                              this);
         connect(job, &KeychainChunk::ReadJob::finished, this, &WebFlowCredentials::slotReadClientCaCertsPEMJobDone);
         job->start();
     } else {
@@ -544,8 +509,6 @@ void WebFlowCredentials::slotReadClientCaCertsPEMJobDone(KeychainChunk::ReadJob
                 _clientSslCaCertificates.append(sslCertificateList.at(0));
             }
 
-            readJob->deleteLater();
-
             // try next cert
             readSingleClientCaCertPEM();
             return;
@@ -555,8 +518,6 @@ void WebFlowCredentials::slotReadClientCaCertsPEMJobDone(KeychainChunk::ReadJob
                 qCWarning(lcWebFlowCredentials) << "Unable to read client CA cert slot" << QString::number(_clientSslCaCertificates.count()) << readJob->errorString();
             }
         }
-
-        readJob->deleteLater();
     }
 
     // Now fetch the actual server password
@@ -565,7 +526,7 @@ void WebFlowCredentials::slotReadClientCaCertsPEMJobDone(KeychainChunk::ReadJob
         _user,
         _keychainMigration ? QString() : _account->id());
 
-    ReadPasswordJob *job = new ReadPasswordJob(Theme::instance()->appName());
+    auto job = new ReadPasswordJob(Theme::instance()->appName(), this);
 #if defined(KEYCHAINCHUNK_ENABLE_INSECURE_FALLBACK)
     addSettingsToJob(_account, job);
 #endif
@@ -576,7 +537,7 @@ void WebFlowCredentials::slotReadClientCaCertsPEMJobDone(KeychainChunk::ReadJob
 }
 
 void WebFlowCredentials::slotReadPasswordJobDone(Job *incomingJob) {
-    QKeychain::ReadPasswordJob *job = qobject_cast<ReadPasswordJob *>(incomingJob);
+    auto job = qobject_cast<ReadPasswordJob *>(incomingJob);
     QKeychain::Error error = job->error();
 
     // If we could not find the entry try the old entries
@@ -599,8 +560,6 @@ void WebFlowCredentials::slotReadPasswordJobDone(Job *incomingJob) {
     }
     emit fetched();
 
-    job->deleteLater();
-
     // If keychain data was read from legacy location, wipe these entries and store new ones
     if (_keychainMigration && _ready) {
         _keychainMigration = false;
@@ -612,19 +571,7 @@ void WebFlowCredentials::slotReadPasswordJobDone(Job *incomingJob) {
 
 void WebFlowCredentials::deleteKeychainEntries(bool oldKeychainEntries) {
     auto startDeleteJob = [this, oldKeychainEntries](QString key) {
-        DeletePasswordJob *job = new DeletePasswordJob(Theme::instance()->appName());
-#if defined(KEYCHAINCHUNK_ENABLE_INSECURE_FALLBACK)
-        addSettingsToJob(_account, job);
-#endif
-        job->setInsecureFallback(false);
-        job->setKey(keychainKey(_account->url().toString(),
-                                key,
-                                oldKeychainEntries ? QString() : _account->id()));
-
-        connect(job, &Job::finished, this, [](QKeychain::Job *job) {
-            DeletePasswordJob *djob = qobject_cast<DeletePasswordJob *>(job);
-            djob->deleteLater();
-        });
+        auto job = new KeychainChunk::DeleteJob(_account, key, oldKeychainEntries, this);
         job->start();
     };
 
@@ -641,27 +588,17 @@ void WebFlowCredentials::deleteKeychainEntries(bool oldKeychainEntries) {
      */
     if(_account->isRemoteWipeRequested_HACK()) {
     // <-- FIXME MS@2019-12-07
+
+        // Also delete key / cert sub-chunks (KeychainChunk takes care of the Windows workaround)
+        // The first chunk (0) has no suffix, to stay compatible with older versions and non-Windows
         startDeleteJob(_user + clientKeyPEMC);
         startDeleteJob(_user + clientCertificatePEMC);
 
+        // CA cert slots
         for (auto i = 0; i < _clientSslCaCertificates.count(); i++) {
             startDeleteJob(_user + clientCaCertificatePEMC + QString::number(i));
         }
 
-#if defined(Q_OS_WIN)
-        // Also delete key / cert sub-chunks (Windows workaround)
-        // The first chunk (0) has no suffix, to stay compatible with older versions and non-Windows
-        for (auto chunk = 1; chunk < KeychainChunk::MaxChunks; chunk++) {
-            const QString strChunkSuffix = QString(".") + QString::number(chunk);
-
-            startDeleteJob(_user + clientKeyPEMC + strChunkSuffix);
-            startDeleteJob(_user + clientCertificatePEMC + strChunkSuffix);
-
-            for (auto i = 0; i < _clientSslCaCertificates.count(); i++) {
-                startDeleteJob(_user + clientCaCertificatePEMC + QString::number(i));
-            }
-        }
-#endif
     // FIXME MS@2019-12-07 -->
     }
     // <-- FIXME MS@2019-12-07
