@@ -14,7 +14,8 @@
  */
 #include <QtGlobal>
 
-#include <signal.h>
+#include <cmath>
+#include <csignal>
 
 #ifdef Q_OS_UNIX
 #include <sys/time.h>
@@ -34,6 +35,7 @@
 #include <QMessageBox>
 #include <QDebug>
 #include <QQuickStyle>
+#include <QQuickWindow>
 
 using namespace OCC;
 
@@ -99,6 +101,15 @@ int main(int argc, char **argv)
         return 0;
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    QQuickWindow::setTextRenderType(QQuickWindow::NativeTextRendering);
+#else
+    // See https://bugreports.qt.io/browse/QTBUG-70481
+    if (std::fmod(app.devicePixelRatio(), 1) == 0) {
+        QQuickWindow::setTextRenderType(QQuickWindow::NativeTextRendering);
+    }
+#endif
+
 // check a environment variable for core dumps
 #ifdef Q_OS_UNIX
     if (!qEnvironmentVariableIsEmpty("OWNCLOUD_CORE_DUMP")) {
