@@ -7,6 +7,7 @@
 #include "ocsjob.h"
 #include "configfile.h"
 #include "notificationconfirmjob.h"
+#include "logger.h"
 
 #include <QDesktopServices>
 #include <QIcon>
@@ -40,11 +41,18 @@ User::User(AccountStatePtr &account, const bool &isCurrent, QObject *parent)
 
     connect(_account.data(), &AccountState::stateChanged,
             [=]() { if (isConnected()) {slotRefresh();} });
+    connect(_account.data(), &AccountState::stateChanged, this, &User::accountStateChanged);
     connect(_account.data(), &AccountState::hasFetchedNavigationApps,
         this, &User::slotRebuildNavigationAppList);
     connect(_account->account().data(), &Account::accountChangedDisplayName, this, &User::nameChanged);
 
     connect(FolderMan::instance(), &FolderMan::folderListChanged, this, &User::hasLocalFolderChanged);
+
+    connect(this, &User::guiLog, Logger::instance(), &Logger::guiLog);
+
+    connect(_account->account().data(), &Account::accountChangedAvatar, this, &User::avatarChanged);
+
+    connect(_activityModel, &ActivityListModel::sendNotificationRequest, this, &User::slotSendNotificationRequest);
 }
 
 void User::slotBuildNotificationDisplay(const ActivityList &list)
@@ -323,7 +331,7 @@ void User::slotAddError(const QString &folderAlias, const QString &message, Erro
             link._label = tr("Retry all uploads");
             link._link = folderInstance->path();
             link._verb = "";
-            link._isPrimary = true;
+            link._primary = true;
             activity._links.append(link);
         }
 
@@ -364,18 +372,19 @@ void User::slotItemCompleted(const QString &folder, const SyncFileItemPtr &item)
             activity._fileAction = "file_changed";
         }
 
-
         if (item->_status == SyncFileItem::NoStatus || item->_status == SyncFileItem::Success) {
             qCWarning(lcActivity) << "Item " << item->_file << " retrieved successfully.";
-            
-            if (activity._fileAction == "file_renamed") {
-                activity._message.prepend(tr("You renamed") + " ");
+
+            if (item->_direction != SyncFileItem::Up) {
+                activity._message = tr("Synced %1").arg(item->_originalFile);
+            } else if (activity._fileAction == "file_renamed") {
+                activity._message = tr("You renamed %1").arg(item->_originalFile);
             } else if (activity._fileAction == "file_deleted") {
-                activity._message.prepend(tr("You deleted") + " ");
+                activity._message = tr("You deleted %1").arg(item->_originalFile);
             } else if (activity._fileAction == "file_created") {
-                activity._message.prepend(tr("You created") + " ");
+                activity._message = tr("You created %1").arg(item->_originalFile);
             } else {
-                activity._message.prepend(tr("You changed") + " ");
+                activity._message = tr("You changed %1").arg(item->_originalFile);
             }
 
             _activityModel->addSyncFileItemToActivityList(activity);
@@ -459,21 +468,18 @@ QString User::server(bool shortened) const
     return serverUrl;
 }
 
-QImage User::avatar(bool whiteBg) const
+QImage User::avatar() const
 {
-    QImage img = AvatarJob::makeCircularAvatar(_account->account()->avatar());
-    if (img.isNull()) {
-        QImage image(128, 128, QImage::Format_ARGB32);
-        image.fill(Qt::GlobalColor::transparent);
-        QPainter painter(&image);
+    return AvatarJob::makeCircularAvatar(_account->account()->avatar());
+}
 
-        QSvgRenderer renderer(QString(whiteBg ? ":/client/theme/black/user.svg" : ":/client/theme/white/user.svg"));
-        renderer.render(&painter);
-
-        return image;
-    } else {
-        return img;
+QString User::avatarUrl() const
+{
+    if (avatar().isNull()) {
+        return QString();
     }
+
+    return QStringLiteral("image://avatars/") + _account->account()->id();
 }
 
 bool User::hasLocalFolder() const
@@ -549,6 +555,7 @@ void UserModel::buildUserList()
     }
     if (_init) {
         _users.first()->setCurrentUser(true);
+        connect(_users.first(), &User::accountStateChanged, this, &UserModel::refreshCurrentUserGui);
         _init = false;
     }
 }
@@ -565,38 +572,23 @@ Q_INVOKABLE int UserModel::currentUserId() const
 
 Q_INVOKABLE bool UserModel::isUserConnected(const int &id)
 {
-    if (_users.isEmpty())
+    if (id < 0 || id >= _users.size())
         return false;
 
     return _users[id]->isConnected();
 }
 
-Q_INVOKABLE QImage UserModel::currentUserAvatar()
-{
-    if (!_users.isEmpty()) {
-        return _users[_currentUserId]->avatar();
-    } else {
-        QImage image(128, 128, QImage::Format_ARGB32);
-        image.fill(Qt::GlobalColor::transparent);
-        QPainter painter(&image);
-        QSvgRenderer renderer(QString(":/client/theme/white/user.svg"));
-        renderer.render(&painter);
-
-        return image;
-    }
-}
-
 QImage UserModel::avatarById(const int &id)
 {
-    if (_users.isEmpty())
+    if (id < 0 || id >= _users.size())
         return {};
 
-    return _users[id]->avatar(true);
+    return _users[id]->avatar();
 }
 
 Q_INVOKABLE QString UserModel::currentUserServer()
 {
-    if (_users.isEmpty())
+    if (_currentUserId < 0 || _currentUserId >= _users.size())
         return {};
 
     return _users[_currentUserId]->server();
@@ -605,19 +597,29 @@ Q_INVOKABLE QString UserModel::currentUserServer()
 void UserModel::addUser(AccountStatePtr &user, const bool &isCurrent)
 {
     bool containsUser = false;
-    for (int i = 0; i < _users.size(); i++) {
-        if (_users[i]->account() == user->account()) {
+    for (const auto &u : qAsConst(_users)) {
+        if (u->account() == user->account()) {
             containsUser = true;
             continue;
         }
     }
 
     if (!containsUser) {
-        beginInsertRows(QModelIndex(), rowCount(), rowCount());
-        _users << new User(user, isCurrent);
+        int row = rowCount();
+        beginInsertRows(QModelIndex(), row, row);
+
+        User *u = new User(user, isCurrent);
+
+        connect(u, &User::avatarChanged, this, [this, row] {
+           emit dataChanged(index(row, 0), index(row, 0), {UserModel::AvatarRole});
+        });
+
+        _users << u;
         if (isCurrent) {
             _currentUserId = _users.indexOf(_users.last());
+            connect(u, &User::accountStateChanged, this, &UserModel::refreshCurrentUserGui);
         }
+
         endInsertRows();
         ConfigFile cfg;
         _users.last()->setNotificationRefreshInterval(cfg.notificationRefreshInterval());
@@ -632,7 +634,7 @@ int UserModel::currentUserIndex()
 
 Q_INVOKABLE void UserModel::openCurrentAccountLocalFolder()
 {
-    if (_users.isEmpty())
+    if (_currentUserId < 0 || _currentUserId >= _users.size())
         return;
 
     _users[_currentUserId]->openLocalFolder();
@@ -653,10 +655,7 @@ Q_INVOKABLE void UserModel::openCurrentAccountTalk()
 
 Q_INVOKABLE void UserModel::openCurrentAccountServer()
 {
-    // Don't open this URL when the QML appMenu pops up on click (see Window.qml)
-    if (appList().count() > 0)
-        return;
-    if (_users.isEmpty())
+    if (_currentUserId < 0 || _currentUserId >= _users.size())
         return;
 
     QString url = _users[_currentUserId]->server(false);
@@ -668,11 +667,13 @@ Q_INVOKABLE void UserModel::openCurrentAccountServer()
 
 Q_INVOKABLE void UserModel::switchCurrentUser(const int &id)
 {
-    if (_users.isEmpty())
+    if (_currentUserId < 0 || _currentUserId >= _users.size())
         return;
 
+    disconnect(_users[_currentUserId], &User::accountStateChanged, this, &UserModel::refreshCurrentUserGui);
     _users[_currentUserId]->setCurrentUser(false);
     _users[id]->setCurrentUser(true);
+    connect(_users[id], &User::accountStateChanged, this, &UserModel::refreshCurrentUserGui);
     _currentUserId = id;
     emit refreshCurrentUserGui();
     emit newUserSelected();
@@ -680,7 +681,7 @@ Q_INVOKABLE void UserModel::switchCurrentUser(const int &id)
 
 Q_INVOKABLE void UserModel::login(const int &id)
 {
-    if (_users.isEmpty())
+    if (id < 0 || id >= _users.size())
         return;
 
     _users[id]->login();
@@ -689,7 +690,7 @@ Q_INVOKABLE void UserModel::login(const int &id)
 
 Q_INVOKABLE void UserModel::logout(const int &id)
 {
-    if (_users.isEmpty())
+    if (id < 0 || id >= _users.size())
         return;
 
     _users[id]->logout();
@@ -698,7 +699,7 @@ Q_INVOKABLE void UserModel::logout(const int &id)
 
 Q_INVOKABLE void UserModel::removeAccount(const int &id)
 {
-    if (_users.isEmpty())
+    if (id < 0 || id >= _users.size())
         return;
 
     QMessageBox messageBox(QMessageBox::Question,
@@ -716,6 +717,10 @@ Q_INVOKABLE void UserModel::removeAccount(const int &id)
         return;
     }
 
+    if (_users[id]->isCurrentUser()) {
+        disconnect(_users[id], &User::accountStateChanged, this, &UserModel::refreshCurrentUserGui);
+    }
+
     if (_users[id]->isCurrentUser() && _users.count() > 1) {
         id == 0 ? switchCurrentUser(1) : switchCurrentUser(0);
     }
@@ -747,7 +752,7 @@ QVariant UserModel::data(const QModelIndex &index, int role) const
     } else if (role == ServerRole) {
         return _users[index.row()]->server();
     } else if (role == AvatarRole) {
-        return _users[index.row()]->avatar();
+        return _users[index.row()]->avatarUrl();
     } else if (role == IsCurrentUserRole) {
         return _users[index.row()]->isCurrentUser();
     } else if (role == IsConnectedRole) {
@@ -772,7 +777,7 @@ QHash<int, QByteArray> UserModel::roleNames() const
 
 ActivityListModel *UserModel::currentActivityModel()
 {
-    if (_users.isEmpty())
+    if (currentUserIndex() < 0 || currentUserIndex() >= _users.size())
         return nullptr;
 
     return _users[currentUserIndex()]->getActivityModel();
@@ -780,7 +785,7 @@ ActivityListModel *UserModel::currentActivityModel()
 
 bool UserModel::currentUserHasActivities()
 {
-    if (_users.isEmpty())
+    if (currentUserIndex() < 0 || currentUserIndex() >= _users.size())
         return false;
 
     return _users[currentUserIndex()]->hasActivities();
@@ -788,7 +793,7 @@ bool UserModel::currentUserHasActivities()
 
 bool UserModel::currentUserHasLocalFolder()
 {
-    if (_users.isEmpty())
+    if (currentUserIndex() < 0 || currentUserIndex() >= _users.size())
         return false;
 
     return _users[currentUserIndex()]->getFolder() != nullptr;
@@ -796,26 +801,42 @@ bool UserModel::currentUserHasLocalFolder()
 
 void UserModel::fetchCurrentActivityModel()
 {
-    if (!_users.isEmpty())
-        _users[currentUserId()]->slotRefresh();
+    if (currentUserId() < 0 || currentUserId() >= _users.size())
+        return;
+
+    _users[currentUserId()]->slotRefresh();
 }
 
 AccountAppList UserModel::appList() const
 {
-    if (_users.isEmpty())
-        return AccountAppList();
+    if (_currentUserId < 0 || _currentUserId >= _users.size())
+        return {};
 
     return _users[_currentUserId]->appList();
 }
 
 User *UserModel::currentUser() const
 {
-    if (_users.isEmpty())
+    if (currentUserId() < 0 || currentUserId() >= _users.size())
         return nullptr;
 
     return _users[currentUserId()];
 }
 
+int UserModel::findUserIdForAccount(AccountState *account) const
+{
+    const auto it = std::find_if(std::cbegin(_users), std::cend(_users), [=](const User *user) {
+        return user->account()->id() == account->account()->id();
+    });
+
+    if (it == std::cend(_users)) {
+        return -1;
+    }
+
+    const auto id = std::distance(std::cbegin(_users), it);
+    return id;
+}
+
 /*-------------------------------------------------------------------------------------*/
 
 ImageProvider::ImageProvider()
@@ -828,12 +849,25 @@ QImage ImageProvider::requestImage(const QString &id, QSize *size, const QSize &
     Q_UNUSED(size)
     Q_UNUSED(requestedSize)
 
-    if (id == "currentUser") {
-        return UserModel::instance()->currentUserAvatar();
-    } else {
-        int uid = id.toInt();
-        return UserModel::instance()->avatarById(uid);
+    const auto makeIcon = [](const QString &path) {
+        QImage image(128, 128, QImage::Format_ARGB32);
+        image.fill(Qt::GlobalColor::transparent);
+        QPainter painter(&image);
+        QSvgRenderer renderer(path);
+        renderer.render(&painter);
+        return image;
+    };
+
+    if (id == QLatin1String("fallbackWhite")) {
+        return makeIcon(QStringLiteral(":/client/theme/white/user.svg"));
     }
+
+    if (id == QLatin1String("fallbackBlack")) {
+        return makeIcon(QStringLiteral(":/client/theme/black/user.svg"));
+    }
+
+    const int uid = id.toInt();
+    return UserModel::instance()->avatarById(uid);
 }
 
 /*-------------------------------------------------------------------------------------*/
