@@ -40,7 +40,7 @@
 #include <QJsonObject>
 #include <QJsonArray>
 
-#include <keychain.h>
+#include <qt5keychain/keychain.h>
 #include "creds/abstractcredentials.h"
 
 using namespace QKeychain;
