@@ -29,13 +29,18 @@ GetFolderEncryptStatusJob::GetFolderEncryptStatusJob(const AccountPtr& account,
 {
 }
 
+QString GetFolderEncryptStatusJob::folder() const
+{
+    return _folder;
+}
+
 void GetFolderEncryptStatusJob::start()
 {
 	QNetworkRequest req;
 	req.setPriority(QNetworkRequest::HighPriority);
 	req.setRawHeader("OCS-APIREQUEST", "true");
     req.setHeader(QNetworkRequest::ContentTypeHeader, QByteArrayLiteral("application/xml"));
-    req.setRawHeader("Depth", "infinity");
+    req.setRawHeader("Depth", "1");
 
 	QByteArray xml = R"(<d:propfind xmlns:d="DAV:"> <d:prop xmlns:nc="http://nextcloud.org/ns"> <nc:is-encrypted/> </d:prop> </d:propfind>)";
 	auto *buf = new QBuffer(this);
