@@ -253,6 +253,7 @@ class OWNCLOUDSYNC_EXPORT MkColJob : public AbstractNetworkJob
 
 public:
     explicit MkColJob(AccountPtr account, const QString &path, QObject *parent = nullptr);
+    explicit MkColJob(AccountPtr account, const QString &path, const QMap<QByteArray, QByteArray> &extraHeaders, QObject *parent = nullptr);
     explicit MkColJob(AccountPtr account, const QUrl &url,
         const QMap<QByteArray, QByteArray> &extraHeaders, QObject *parent = nullptr);
     void start() override;
@@ -333,7 +334,7 @@ public:
     void start() override;
 
 signals:
-    void etagRetreived(const QString &etag);
+    void etagRetrieved(const QString &etag);
 
 private slots:
     bool finished() override;
@@ -373,6 +374,16 @@ public:
     void addQueryParams(const QUrlQuery &params);
     void addRawHeader(const QByteArray &headerName, const QByteArray &value);
 
+    /**
+     * @brief usePOST - allow job to do an anonymous POST request instead of GET
+     * @param params: (optional) true for POST, false for GET (default).
+     *
+     * This function needs to be called before start() obviously.
+     */
+    void usePOST(bool usePOST = true) {
+        _usePOST = usePOST;
+    }
+
 public slots:
     void start() override;
 
@@ -398,6 +409,8 @@ signals:
 private:
     QUrlQuery _additionalParams;
     QNetworkRequest _request;
+
+    bool _usePOST = false;
 };
 
 /**
