@@ -404,24 +404,21 @@ void OwncloudPropagator::start(const SyncFileItemVector &items,
             // this is an item in a directory which is going to be removed.
             auto *delDirJob = qobject_cast<PropagateDirectory *>(directoriesToRemove.first());
 
-            if (item->_instruction == CSYNC_INSTRUCTION_REMOVE) {
-                // already taken care of. (by the removal of the parent directory)
+            const auto isNewDirectory = item->isDirectory() &&
+                    (item->_instruction == CSYNC_INSTRUCTION_NEW || item->_instruction == CSYNC_INSTRUCTION_TYPE_CHANGE);
+
+            if (item->_instruction == CSYNC_INSTRUCTION_REMOVE || isNewDirectory) {
+                // If it is a remove it is already taken care of by the removal of the parent directory
+
+                // If it is a new directory then it is inside a deleted directory... That can happen if
+                // the directory etag was not fetched properly on the previous sync because the sync was
+                // aborted while uploading this directory (which is now removed).  We can ignore it.
 
                 // increase the number of subjobs that would be there.
                 if (delDirJob) {
                     delDirJob->increaseAffectedCount();
                 }
                 continue;
-            } else if (item->isDirectory()
-                && (item->_instruction == CSYNC_INSTRUCTION_NEW
-                       || item->_instruction == CSYNC_INSTRUCTION_TYPE_CHANGE)) {
-                // create a new directory within a deleted directory? That can happen if the directory
-                // etag was not fetched properly on the previous sync because the sync was aborted
-                // while uploading this directory (which is now removed).  We can ignore it.
-                if (delDirJob) {
-                    delDirJob->increaseAffectedCount();
-                }
-                continue;
             } else if (item->_instruction == CSYNC_INSTRUCTION_IGNORE) {
                 continue;
             } else if (item->_instruction == CSYNC_INSTRUCTION_RENAME) {
@@ -796,16 +793,16 @@ bool PropagatorCompositeJob::scheduleSelfOrChild()
     }
 
     // Ask all the running composite jobs if they have something new to schedule.
-    for (int i = 0; i < _runningJobs.size(); ++i) {
-        ASSERT(_runningJobs.at(i)->_state == Running);
+    for (auto runningJob : qAsConst(_runningJobs)) {
+        ASSERT(runningJob->_state == Running);
 
-        if (possiblyRunNextJob(_runningJobs.at(i))) {
+        if (possiblyRunNextJob(runningJob)) {
             return true;
         }
 
         // If any of the running sub jobs is not parallel, we have to cancel the scheduling
         // of the rest of the list and wait for the blocking job to finish and schedule the next one.
-        auto paral = _runningJobs.at(i)->parallelism();
+        auto paral = runningJob->parallelism();
         if (paral == WaitForFinished) {
             return false;
         }
