@@ -130,7 +130,7 @@ private slots:
 
     void testDownloadInfo()
     {
-        typedef SyncJournalDb::DownloadInfo Info;
+        using Info = SyncJournalDb::DownloadInfo;
         Info record = _db.getDownloadInfo("nonexistant");
         QVERIFY(!record._valid);
 
@@ -150,7 +150,7 @@ private slots:
 
     void testUploadInfo()
     {
-        typedef SyncJournalDb::UploadInfo Info;
+        using Info = SyncJournalDb::UploadInfo;
         Info record = _db.getUploadInfo("nonexistant");
         QVERIFY(!record._valid);
 
